
Channel Information System
==========================

.. |date| date::
.. |time| date:: %H:%M

This document was built from version |version|,  |today| at |time|


.. toctree::
   :maxdepth: 2
   :caption: Contents:



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
